containerimagehandler

package
v0.669.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

README

containerimagehandler

Handle container images without a runnig daemon like Docker. This makes the handling fast and available in buildsystems where no Docker or other container runtime is available.

Examples:

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddFileToArchive added in v0.531.0

func AddFileToArchive(ctx context.Context, archivePath string, options *containeroptions.AddFileToImageArchiveOptions) error

func AddFileToImage added in v0.550.0

func AddFileToImage(ctx context.Context, image v1.Image, options *containeroptions.AddFileToImageOptions) (v1.Image, error)

func CreateSingleFileArchive added in v0.545.0

func CreateSingleFileArchive(ctx context.Context, outputPath string, options *containeroptions.CreateSingleFileArchiveOptions) error

func DeleteFileInArchive added in v0.531.0

func DeleteFileInArchive(ctx context.Context, archivePath string, options *containeroptions.DeleteFileFromImageOptions) error

func DownloadImage added in v0.550.0

func DownloadImage(ctx context.Context, imageNameAndTag string) (v1.Image, name.Reference, error)

func DownloadImageAsArchive

func DownloadImageAsArchive(ctx context.Context, imageNameAndTag string, outputPath string) error

func DownloadImageAsTeporaryArchive added in v0.531.0

func DownloadImageAsTeporaryArchive(ctx context.Context, imageNameAndTag string) (string, error)

func FileInArchiveExists added in v0.531.0

func FileInArchiveExists(ctx context.Context, archivePath string, pathToCheck string) (bool, error)

func ListFilesInArchive added in v0.531.0

func ListFilesInArchive(ctx context.Context, archivePath string) ([]string, error)

func ListImageNamesAndTagsInArchive added in v0.531.0

func ListImageNamesAndTagsInArchive(ctx context.Context, archivePath string) ([]string, error)

func LoadImageFromArchive added in v0.531.0

func LoadImageFromArchive(ctx context.Context, archivePath string, imageNameAndTag string) (v1.Image, *name.Tag, error)

Load the image tagged as "imageNameAndTag" from a container image archive.

If imageNammeAndTag is empty the tag is evaluated based on the archive content. This will fail when multiple tags are defined in one archive. In the case of multiple tags the tag has to be explicitly defined as imageNameAndTag

func OverwriteArchive added in v0.531.0

func OverwriteArchive(ctx context.Context, archivePath string, tag *name.Tag, image v1.Image) error

func PushImage added in v0.550.0

func PushImage(ctx context.Context, image v1.Image, nameAndTag string) error

func ReadFileFromArchiveAsBytes added in v0.531.0

func ReadFileFromArchiveAsBytes(ctx context.Context, archivePath string, toReadPath string) ([]byte, error)

func ReadFileFromArchiveAsString added in v0.531.0

func ReadFileFromArchiveAsString(ctx context.Context, archivePath string, toReadPath string) (string, error)

Types

This section is empty.

Jump to