Documentation
¶
Index ¶
- func AddFileToArchive(ctx context.Context, archivePath string, ...) error
- func AddFileToImage(ctx context.Context, image v1.Image, ...) (v1.Image, error)
- func CreateSingleFileArchive(ctx context.Context, outputPath string, ...) error
- func DeleteFileInArchive(ctx context.Context, archivePath string, ...) error
- func DownloadImage(ctx context.Context, imageNameAndTag string) (v1.Image, name.Reference, error)
- func DownloadImageAsArchive(ctx context.Context, imageNameAndTag string, outputPath string) error
- func DownloadImageAsTeporaryArchive(ctx context.Context, imageNameAndTag string) (string, error)
- func FileInArchiveExists(ctx context.Context, archivePath string, pathToCheck string) (bool, error)
- func ListFilesInArchive(ctx context.Context, archivePath string) ([]string, error)
- func ListImageNamesAndTagsInArchive(ctx context.Context, archivePath string) ([]string, error)
- func LoadImageFromArchive(ctx context.Context, archivePath string, imageNameAndTag string) (v1.Image, *name.Tag, error)
- func OverwriteArchive(ctx context.Context, archivePath string, tag *name.Tag, image v1.Image) error
- func PushImage(ctx context.Context, image v1.Image, nameAndTag string) error
- func ReadFileFromArchiveAsBytes(ctx context.Context, archivePath string, toReadPath string) ([]byte, error)
- func ReadFileFromArchiveAsString(ctx context.Context, archivePath string, toReadPath string) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddFileToArchive ¶ added in v0.531.0
func AddFileToArchive(ctx context.Context, archivePath string, options *containeroptions.AddFileToImageArchiveOptions) error
func AddFileToImage ¶ added in v0.550.0
func AddFileToImage(ctx context.Context, image v1.Image, options *containeroptions.AddFileToImageOptions) (v1.Image, error)
func CreateSingleFileArchive ¶ added in v0.545.0
func CreateSingleFileArchive(ctx context.Context, outputPath string, options *containeroptions.CreateSingleFileArchiveOptions) error
func DeleteFileInArchive ¶ added in v0.531.0
func DeleteFileInArchive(ctx context.Context, archivePath string, options *containeroptions.DeleteFileFromImageOptions) error
func DownloadImage ¶ added in v0.550.0
func DownloadImageAsArchive ¶
func DownloadImageAsTeporaryArchive ¶ added in v0.531.0
func FileInArchiveExists ¶ added in v0.531.0
func ListFilesInArchive ¶ added in v0.531.0
func ListImageNamesAndTagsInArchive ¶ added in v0.531.0
func LoadImageFromArchive ¶ added in v0.531.0
func LoadImageFromArchive(ctx context.Context, archivePath string, imageNameAndTag string) (v1.Image, *name.Tag, error)
Load the image tagged as "imageNameAndTag" from a container image archive.
If imageNammeAndTag is empty the tag is evaluated based on the archive content. This will fail when multiple tags are defined in one archive. In the case of multiple tags the tag has to be explicitly defined as imageNameAndTag
func OverwriteArchive ¶ added in v0.531.0
func ReadFileFromArchiveAsBytes ¶ added in v0.531.0
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.